import defu from "defu";
import { murmurHashV3 } from "murmurhash-es";
import { useNuxtApp, useRuntimeConfig, useAsyncData, useLazyAsyncData } from "#app";
import { createSanityClient } from "#imports";
const createSanityHelper = (options) => {
  const config = options;
  let client = createSanityClient(config);
  return {
    client,
    config,
    fetch: (...args) => client.fetch(...args),
    setToken(token) {
      config.token = token;
      client = createSanityClient(config);
    }
  };
};
export const useSanity = (client = "default") => {
  const nuxtApp = useNuxtApp();
  if (nuxtApp._sanity?.[client]) {
    return nuxtApp._sanity[client];
  }
  nuxtApp._sanity = nuxtApp._sanity || {};
  const $config = useRuntimeConfig();
  const { additionalClients = {}, ...options } = $config.sanity;
  if (!options.disableSmartCdn && nuxtApp.$preview) {
    options.useCdn = false;
  }
  if (client === "default") {
    nuxtApp._sanity.default = createSanityHelper(options);
    return nuxtApp._sanity.default;
  }
  nuxtApp._sanity[client] = createSanityHelper(defu(additionalClients[client], options));
  return nuxtApp._sanity[client];
};
export const useSanityQuery = (query, params, options = {}) => {
  const { client, ..._options } = options;
  const sanity = useSanity(client);
  return useAsyncData("sanity-" + murmurHashV3(query + (params ? JSON.stringify(params) : "")), () => sanity.fetch(query, params), _options);
};
export const useLazySanityQuery = (query, params, options = {}) => {
  const { client, ..._options } = options;
  const sanity = useSanity(client);
  return useLazyAsyncData("sanity-" + murmurHashV3(query + (params ? JSON.stringify(params) : "")), () => sanity.fetch(query, params), _options);
};
